API
====================================

.. autofunction:: bib_dedupe.bib_dedupe.prep


.. autofunction:: bib_dedupe.bib_dedupe.block


.. autofunction:: bib_dedupe.bib_dedupe.match


.. autofunction:: bib_dedupe.bib_dedupe.export_maybe


.. autofunction:: bib_dedupe.bib_dedupe.import_maybe


.. autofunction:: bib_dedupe.bib_dedupe.merge
